import ajax from '@/utils/request.js';
import ajaxAxios from '@/utils/request_axios.js';

/**
 * 广告
 * @returns {AxjxPromise}
 */
export function advertisementApi(data) {
  return ajax({
    url: '/kuyun_eye_ad/cbd_public/perform',
    method: 'get',
    data,
  });
}
/**
 * 流入流出
 * @returns {AxjxPromise}
 */
export function inOutApi(data) {
  return ajax({
    url: '/api/recent_inout',
    method: 'get',
    data,
  });
}
/**
 * epg
 * @returns {AxjxPromise}
 */
export function epgApi(data) {
  return ajax({
    url: '/api/recent_epgs',
    method: 'get',
    data,
  });
}
/**
 * 直播实时 分
 * @returns {AxjxPromise}
 */
export function liveRealDataMinApi(data) {
  return ajax({
    url: '/api/sec_ratings',
    method: 'get',
    data,
  });
}
/**
 * 直播实时数据
 * @returns {AxjxPromise}
 */
export function liveRealDataApi(data) {
  return ajax({
    url: '/api//rtmin',
    method: 'get',
    data,
  });
}
/**
 * 直播实时数据
 * @returns {AxjxPromise}
 */
export function liveDataApi(data) {
  return ajax({
    url: '/api/tvlb',
    method: 'get',
    data,
  });
}
/**
 * 高光数据
 * @returns {AxjxPromise}
 */
export function heightlightDataApi(data) {
  return ajax({
    url: '/api/hl/calendar',
    method: 'get',
    data,
  });
}
/**
 * 高光时刻
 * @returns {AxjxPromise}
 */
export function heightlightApi(data) {
  return ajax({
    url: '/api/hl/list-milestone',
    method: 'get',
    data,
  });
}
/**
 * 节目
 * @returns {AxjxPromise}
 */
export function list(data) {
  return ajax({
    url: '/api/proepglb',
    method: 'get',
    resType: 't200',
    data,
  });
}
/**
 * 节目导出
 * @returns {AxjxPromise}
 */
export function listcsv(data) {
  return ajax({
    url: '/api/proepglb/csv',
    method: 'get',
    downCsv: true,
    data,
  });
}
/**
 * 频道
 * @returns {AxjxPromise}
 */
export function channel(data) {
  return ajax({
    url: '/api/protvlb',
    resType: 't200',
    method: 'get',
    data,
  });
}
/**
 * 频道导出
 * @returns {AxjxPromise}
 */
export function channelcsv(data) {
  return ajax({
    url: '/api/protvlb/csv',
    resType: 't200',
    method: 'get',
    downCsv: true,
    data,
  });
}

/**
 * 获取精品节目列表
 * @props {}
 * @returns {AxjxPromise}
 */
export function epgList() {
  return ajax({
    urlType: 'url2',
    url: '/program',
    method: 'get',
  });
}
/**
 * 获取精品节目详情
 * @props {}
 * @returns {AxjxPromise}
 */
export function epgDetail(data) {
  return ajax({
    urlType: 'url2',
    url: '/epg-detail',
    method: 'get',
    target: data.target,
    data: { epgId: data.epgId },
  });
}
/**
 * 获取精品节目指标
 * @props {}
 * @returns {AxjxPromise}
 */
export function epgResult(data) {
  return ajax({
    urlType: 'url2',
    url: '/epg-result',
    method: 'get',
    data,
  });
}

/**
 * 自由接口
 * @props {url, data}
 * @return {AxjxPromise}
 */
export function defaultAjax(props) {
  return ajax({
    urlType: 'url3',
    url: props.url,
    method: 'get',
    notLoad: props.notLoad,
    target: props.target,
    data: props.data,
  });
}

/**
 * 频率列表
 * @props {}
 * @return {AxjxPromise}
 */
export function frequencyList() {
  return ajax({
    urlType: 'url2',
    url: '/broadcast/dict',
    method: 'get',
  });
}
/**
 * 频率查询
 * @props {}
 * @return {AxjxPromise}
 */
export function PLList(data) {
  return ajax({
    urlType: 'url2',
    url: '/broadcast/list',
    method: 'get',
    data,
  });
}

// 全国接口

/**
 * 频道全天节目
 * 表格查询
 * @props {}
 * @return {AxjxPromise}
 */
export function allDayEpg(data) {
  return ajax({
    urlType: 'kuyunApi',
    url: '/broadcast/list',
    method: 'get',
    data,
  });
}
// 重叠度

/**
 * 节目查询
 * 图表查询
 * @props {}
 * @return {AxjxPromise}
 */
export function overlapSearchTitle(data) {
  return ajax({
    urlType: 'kuyunApi',
    url: '/api/evaluation/eye/search_suggest?' + data,
    method: 'GET',
  });
}
/**
 * 节目重叠度
 * 图表查询
 * @props {}
 * @return {AxjxPromise}
 */
export function overlap(data) {
  return ajax({
    urlType: 'kuyunApi',
    url: '/ProUserOverlapAction',
    method: 'GET',
    data,
  });
}

/**
 * 广告频道列表
 * @props {}
 * @return {AxjxPromise}
 */
export function adChannelList() {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/channel',
    method: 'GET',
  });
}

/**
 * 投放分析
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function launchList(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/day',
    method: 'POST',
    data,
  });
}

/**
 * 时段分析
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function trendList(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/hour',
    method: 'POST',
    data,
  });
}

/**
 * 行业占比
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function proportionList(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/ratio',
    method: 'POST',
    data,
  });
}

/**
 * 客户投放详情
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function customerList(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/detail',
    method: 'POST',
    data,
  });
}

/**
 * 优势客户
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function advantageousList(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/youshi',
    method: 'POST',
    data,
  });
}

/**
 * 潜在客户
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function potentialList(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/qianzai',
    method: 'POST',
    data,
  });
}

/**
 * 饱和度
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function saturationList(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/saturation',
    method: 'POST',
    data,
  });
}

/**
 * 行业列表
 * @return {AxjxPromise}
 */
export function allindustryList(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/industry/list',
    method: 'GET',
    data,
  });
}

/**
 * 全行业
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function industryList(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/market',
    method: 'POST',
    data,
  });
}

/***************************************分行业 */

/**
 * 分行业硬广
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function byIndustryTrendHard(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/industry/TrendHard',
    method: 'POST',
    data,
  });
}
/**
 * 分行业软广
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function byIndustryTrendSoft(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/industry/TrendSoft',
    method: 'POST',
    data,
  });
}

/**
 * 中小行业占比
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function smallIndustryProportion(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/industry/MSIndustryProportion',
    method: 'POST',
    data,
  });
}

/**
 * 媒体份额
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function MediaShare(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/industry/MediaShare',
    method: 'POST',
    data,
  });
}

/**
 * 频道份额
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function ChannelDistribution(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/industry/ChannelDistribution',
    method: 'POST',
    data,
  });
}

/**
 * 节目类型
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function ProgramTypeDistribution(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/industry/ProgramTypeDistribution',
    method: 'POST',
    data,
  });
}

/**
 * 节目类型
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function ProgramTypeDistributionChart(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/industry/ProgramTypeDistributionTable',
    method: 'POST',
    data,
  });
}

/**
 * 重点客户
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function ImportantCustomer(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/industry/ImportantCustomer',
    method: 'POST',
    data,
  });
}

/**
 * 周走势
 * @props {string} tableType
 * @props {string} indexTime
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function LastWeekTrend(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/industry/LastWeekTrend',
    method: 'POST',
    data,
  });
}

/**
 * 品牌top
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function BrandTop(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/index/brand',
    method: 'POST',
    data,
  });
}

/**
 * 品牌top
 * @props {string} dataType
 * @return {AxjxPromise}
 */
export function ChannelTop(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/index/channel',
    method: 'POST',
    data,
  });
}

/**
 * 投放分析
 * @props {string} channelId
 * @props {string} start
 * @props {string} end
 * @return {AxjxPromise}
 */
export function channelRank(data) {
  return ajax({
    urlType: 'adAPI',
    url: '/ad/channel/rank',
    method: 'POST',
    data,
  });
}

/**
 * 获取平台信息数据
 * @props {string} end
 * @return {AxjxPromise}
 */
export function platform(data) {
  return ajax({
    urlType: 'url2',
    url: '/new-media/agg',
    method: 'POST',
    data,
  });
}

/**
 * 获取平台信息数据
 * @props {string} end
 * @return {AxjxPromise}
 */
export function platformlistData(data) {
  return ajax({
    urlType: 'url2',
    url: '/new-media/list',
    method: 'POST',
    data,
  });
}

/**
 * 获取平台信息列表
 * @props {string} end
 * @return {AxjxPromise}
 */
export function platformList(data) {
  return ajax({
    urlType: 'url2',
    url: '/new-media/platform' + (data || ''),
    method: 'POST',
  });
}

/**
 * 归集登录
 * @return {AxjxPromise}
 */
export function guijiLogin(data) {
  return ajaxAxios({
    url: '/login-v2',
    method: 'POST',
    data,
  });
}

/**
 * 归集活动接口
 * @return {AxjxPromise}
 */
export function guijiActivity(data) {
  return ajaxAxios({
    url: '/activity/list',
    method: 'POST',
    data,
  });
}

/**
 * 归集话题
 * @props {string} activityId
 * @return {AxjxPromise}
 */
export function guijiTopic(data) {
  return ajaxAxios({
    url: '/topic/list',
    method: 'POST',
    data,
  });
}

/**
 * 传播数据
 * @props {string} topic
 * @return {AxjxPromise}
 */
export function guijiSpread(data) {
  return ajaxAxios({
    url: '/topic/overview?topic=' + data.topic,
    method: 'GET',
  });
}

/**
 * 传播量趋势
 * @props {string} topic
 * @return {AxjxPromise}
 */
export function guijiTrend(data) {
  return ajaxAxios({
    url: '/topic/history?topic=' + data.topic,
    method: 'GET',
  });
}

/**
 * 部门传播量排行
 * @props {string} depRange
 * @props {string} title
 * @return {AxjxPromise}
 */
export function guijiDepartment(data) {
  return ajaxAxios({
    url: '/topic/read',
    method: 'POST',
    data,
  });
}

/**
 * 热点报道
 * @props {string} topic
 * @return {AxjxPromise}
 */
export function guijiHottopic(data) {
  return ajaxAxios({
    url: '/charts/hot-topic?topic=' + data.topic,
    method: 'GET',
  });
}

/**
 * 部门列表
 * @return {AxjxPromise}
 */
export function guijiBumenList() {
  return ajaxAxios({
    url: '/topic/dep-dict',
    method: 'GET',
  });
}

/**
 * 发稿统计
 * @return {AxjxPromise}
 */
export function guijiFagao(data) {
  return ajaxAxios({
    url: '/topic/detail',
    method: 'POST',
    data,
  });
}

/**
 * 发稿统计
 * @return {AxjxPromise}
 */
export function leverAudience(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/flow/channels',
    method: 'GET',
    data,
  });
}

/**
 * 广播重点数据
 * @return {AxjxPromise}
 */
export function audioKeyGet(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-radio-rate/radio-program-rate',
    method: 'POST',
    data,
  });
}

/**
 * 广播数据
 * @return {AxjxPromise}
 */
export function audioGet(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-radio-rate/radio-rate',
    method: 'POST',
    data,
  });
}

/**
 * 广播列表
 * @return {AxjxPromise}
 */
export function audioList(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-radio-rate/radio-names',
    method: 'GET',
    data,
  });
}

/**
 * 广播地区列表
 * @return {AxjxPromise}
 */
export function audioAreaList() {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-radio-rate/area-names',
    method: 'GET',
  });
}

/**
 * 获取app在线实时数
 * @return {AxjxPromise}
 */
export function getRealAppOnline(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/realTime/data',
    method: 'GET',
    data,
  });
}

/**
 * 获取大数据平台检索条件的权限
 * @return {AxjxPromise}
 */
export function getRule(data) {
  const parent = window.parent;
  let token = parent.localStorage.token || '';

  return ajax({
    urlType: 'leverAudience',
    url: '/rmtrate/NODE/SEQ/roleCtrl/findRoleCtrl',
    method: 'POST',
    headers: {
      UserInfo: token,
      requestid: 'tv' + Date.now(),
    },
    data,
  });
}

/**
 * 获取大数据平台应用列表
 * @return {AxjxPromise}
 */
export function getAppList(data) {
  const parent = window.parent.localStorage;
  let token = parent.token || '';
  return ajax({
    urlType: 'leverAudience',
    url: '/rmtrate/sysparam/info',
    method: 'POST',
    headers: {
      UserInfo: token,
      requestid: 'tv' + Date.now(),
    },
    data,
  });
}

/**
 * 获取大数据平台app历史数据
 * @return {AxjxPromise}
 */
export function getHistory(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/user/trend',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台指定应用的版本号，渠道
 * @return {AxjxPromise}
 */
export function getSearchData(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/param/info',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台内容分析 Top10；
 * @return {AxjxPromise}
 */
export function getContentTop10(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/content/top10',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台内容分析 检索内容汇总new-media；
 * @return {AxjxPromise}
 */
export function getContentTotle(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/content/total',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台内容分析 图形；
 * @return {AxjxPromise}
 */
export function getContentChart(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/content/dt',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台内容分析 表格；
 * @return {AxjxPromise}
 */
export function getContentPage(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/content/list',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台新用户留存分析 表格；
 * @return {AxjxPromise}
 */
export function getKeepPage(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/user/keep',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台活跃用户留存分析 表格；
 * @return {AxjxPromise}
 */
export function getActivePage(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/user/active-keep',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台新用户留存分析 表格；
 * @return {AxjxPromise}
 */
export function getSearchPage(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/search/list',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台新用户留存分析 top10；
 * @return {AxjxPromise}
 */
export function getSearchTop10(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/search/top10',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台版本分析 表格；
 * @return {AxjxPromise}
 */
export function getVersionPage(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/user/version',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台版本分析 图表；
 * @return {AxjxPromise}
 */
export function getVersionChart(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/user/version-dt',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台直播分析 表格；
 * @return {AxjxPromise}
 */
export function getLivePage(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/live/list',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台地域分析 地图；
 * @return {AxjxPromise}
 */
export function getRegionChart(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/user/area',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台地域分析 地图级别分类；
 * @return {AxjxPromise}
 */
export function getMaplever(data) {
  return ajax({
    urlType: 'url2',
    url: '/new-media/user/area-range',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台渠道分析 图表；
 * @return {AxjxPromise}
 */
export function getChannleChart(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/user/manufacturer-dt',
    method: 'POST',
    data,
  });
}
/**
 * 获取大数据平台渠道分析 页面；
 * @return {AxjxPromise}
 */
export function getChannlePage(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/user/manufacturer',
    method: 'POST',
    data,
  });
}

/**
 * 获取大数据平台概览数据；
 * @return {AxjxPromise}
 */
export function getOverviewPage(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/overview',
    method: 'POST',
    data,
  });
}

/**
 * 获取大数据平台概-览用户概览数据；
 * @return {AxjxPromise}
 */
export function getUserOverviewPage(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/overview/user',
    method: 'POST',
    data,
  });
}

/**
 * 获取大数据平台概览-地域概览数据；
 * @return {AxjxPromise}
 */
export function getAreaOverviewPage(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/overview/area',
    method: 'POST',
    data,
  });
}

/**
 * 获取大数据平台新媒体用户活跃度数据；
 * @return {AxjxPromise}
 */
export function getUserActivity(data) {
  return ajax({
    urlType: 'leverAudience',
    url: '/cxzx-program/new-media/user/activity/list-v2',
    method: 'POST',
    data,
  });
}

/**
 * 已发稿件数量排行榜
 * @return {AxjxPromise}
 */
export function getArticleCnt(data) {
  return ajax({
    urlType: 'rankApi',
    url: '/article/articleCnt',
    method: 'GET',
    data,
  });
}

/**
 * 稿件传播量排行榜
 * @return {AxjxPromise}
 */
export function getArticlePv(data) {
  return ajax({
    urlType: 'rankApi',
    url: '/article/articlePv',
    method: 'GET',
    data,
  });
}

/**
 * 融合号粉丝量排行榜
 * @return {AxjxPromise}
 */
export function getFansCnt(data) {
  return ajax({
    urlType: 'rankApi',
    url: '/fans/fansCnt',
    method: 'GET',
    data,
  });
}

/**
 * 融合号粉丝量排行榜分类数据
 * @return {AxjxPromise}
 */
export function getAccountType(data) {
  return ajax({
    urlType: 'rankApi',
    url: '/ronghe/accountType',
    method: 'GET',
    data,
  });
}

/**
 * 融合号稿件数量排行榜
 * @return {AxjxPromise}
 */
export function getRongheArticleCnt(data) {
  return ajax({
    urlType: 'rankApi',
    url: '/ronghe/articleCnt',
    method: 'GET',
    data,
  });
}

/**
 * 融合号稿件传播量排行榜
 * @return {AxjxPromise}
 */
export function getRongheArticlePv(data) {
  return ajax({
    urlType: 'rankApi',
    url: '/ronghe/articlePv',
    method: 'GET',
    data,
  });
}

/**
 * 素材贡献量排行榜
 * @return {AxjxPromise}
 */
export function getMaterialCnt(data) {
  return ajax({
    urlType: 'rankApi',
    url: '/material/materialCnt',
    method: 'GET',
    data,
  });
}

/**
 * 素材贡献量排行榜
 * @return {AxjxPromise}
 */
export function getCategoryCnt(data) {
  return ajax({
    urlType: 'rankApi',
    url: '/article/categoryCnt',
    method: 'GET',
    data,
  });
}

/**
 * 素材贡献量排行榜分类数据
 * @return {AxjxPromise}
 */
export function getCategoryType(data) {
  return ajax({
    urlType: 'rankApi',
    url: '/article/categoryType',
    method: 'GET',
    data,
  });
}

/**
 * 直播数据
 * @return {AxjxPromise}
 */
export function getLiveCnt(data) {
  return ajax({
    urlType: 'rankApi',
    url: '/live/liveCnt',
    method: 'GET',
    data,
  });
}

/**
 * app平台用户数
 * @return {AxjxPromise}
 */
export function getUserTotal(data) {
  return ajax({
    urlType: 'url2',
    url: '/new-media/user/total',
    method: 'POST',
    data,
  });
}

/**
 * app平台用户数
 * @return {AxjxPromise}
 */
export function selectColumns(data) {
  return ajax({
    urlType: 'url2',
    url: '/new-media/select/columns',
    method: 'GET',
    data,
  });
}

/**
 * 直播概览
 * @return {AxjxPromise}
 */
export function getLiveOverview(data) {
  return ajax({
    urlType: 'url2',
    url: '/new-media/cloud-live/agg',
    method: 'POST',
    data,
  });
}

/**
 * 直播概览
 * @return {AxjxPromise}
 */
export function getLiveByCol(data) {
  return ajax({
    urlType: 'url2',
    url: '/new-media/cloud-live/aggByColumn',
    method: 'POST',
    data,
  });
}

/**
 * 获取app对应栏目
 * @return {AxjxPromise}
 */
export function getAppColumn(data) {
    return ajax({
      urlType: 'leverAudience',
      url: '/cxzx-program/new-media/content/channels',
      method: 'POST',
      data,
    });
  }
